<?php
/**
 * Customize header settings and it's relative
 *
 * @package FaceBlog
 */

add_action( 'customize_register', 'faceblog_header_settings_register' );

function faceblog_header_settings_register( $wp_customize ) {
	/**
     * Add Header Settings Panel 
     */
    $wp_customize->add_panel(
        'faceblog_header_settings_panel', 
        array(
            'priority'       => 3,
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Header Settings', 'faceblog' ),
            ) 
    );

/*------------------------------------------------------------------------------------------------------*/
    /**
     * Header Menu Section
     */
    $wp_customize->add_section(
        'faceblog_header_menu_section',
        array(
            'title'         => __( 'Menu Section', 'faceblog' ),
            'priority'      => 4,
            'panel'         => 'faceblog_header_settings_panel'
        )
    );

    // Menu Featured Image
    $wp_customize->add_setting( 
        'menu_featured_image',
        array(
            'default' => '',
            'capability'  => 'edit_theme_options',
            'sanitize_callback' => 'esc_url_raw',
            ) 
    );
    $wp_customize->add_control( new WP_Customize_Image_Control( 
        $wp_customize, 
            'menu_featured_image', 
            array(
                'label'     => __( 'Menu Featured Image', 'faceblog' ),
                'section'   => 'faceblog_header_menu_section',
                'context'   => 'header-banner-image',
                'priority'  => 3,
                )
        )
    );

    // Menu featured title
    $wp_customize->add_setting(
        'menu_featured_text', 
        array(
              'default' => __( 'Welcome To Faceblog', 'faceblog' ),
              'capability' => 'edit_theme_options',
              'transport'=> 'postMessage',
              'sanitize_callback' => 'faceblog_sanitize_text',
            )
    );
  $wp_customize->add_control(
      'menu_featured_text', 
      array(
            'type' => 'text',
            'label' => __( 'Menu Featured Text', 'faceblog' ),
            'section' => 'faceblog_header_menu_section',
            'priority' => 4
          )
  );

/*------------------------------------------------------------------------------------------------------*/
    /**
     * FrontPage Banner Section
     */
    $wp_customize->add_section(
        'faceblog_frontpage_banner_section',
        array(
            'title'         => __( 'Frontpage Banner Section', 'faceblog' ),
            'priority'      => 5,
            'panel'         => 'faceblog_header_settings_panel'
        )
    );
    
    // Header option
    $wp_customize->add_setting(
        'faceblog_header_layout',
        array(
            'default' =>'banner_layout1',
            'sanitize_callback' => 'faceblog_header_layout_sanitize',
        )
    );
    $wp_customize->add_control(
        'faceblog_header_layout',
        array(
            'type' => 'radio',
            'priority'    => 3,
            'label' => __( 'Banner Layout', 'faceblog' ),
            'description' => __( 'Choose layout for header banner', 'faceblog' ),
            'section' => 'faceblog_frontpage_banner_section',
            'choices' => array(
                'banner_layout1'   => __( 'Category Posts', 'faceblog' ),
                'banner_layout2'   => __( 'Single Banner', 'faceblog' ),
            ),
        )
    );

    // Category for header section
    $wp_customize->add_setting(
        'header_banner_cat',
        array(
            'default' => '',
            'capability' => 'edit_theme_options',
            'sanitize_callback' => '__return_false_value'
        )
    );
    $wp_customize->add_control( 
        new WP_Customize_Category_Control( 
        $wp_customize,
        'header_banner_cat', 
        array(
            'label' => __( 'Select Category', 'faceblog' ),
            'description' => __( 'Select category for header banner section posts.', 'faceblog' ),
            'section' => 'faceblog_frontpage_banner_section',
            'priority' => 5,
            'active_callback' => 'banner_layout_category_cb'
            )
        )
    );

    // Banner image upload
    $wp_customize->add_setting( 
        'header_front_banner_image',
        array(
            'default' => '',
            'capability'  => 'edit_theme_options',
            'sanitize_callback' => 'esc_url_raw',
            ) 
    );
    $wp_customize->add_control( new WP_Customize_Image_Control( 
        $wp_customize, 
            'header_front_banner_image', 
            array(
                'label'     => __( 'Banner Image', 'faceblog' ),
                'description'     => __( 'Added banner image for Frontpage header section.', 'faceblog' ),
                'section'   => 'faceblog_frontpage_banner_section',
                'context'   => 'header-banner-image',
                'priority'  => 6,
                'active_callback' => 'banner_layout_image_cb'
                )
        ) 
    );
/*------------------------------------------------------------------------------------------------------*/
    /**
     * Innerpages Banner Section
     */
    $wp_customize->add_section(
        'faceblog_innerpage_banner_section',
        array(
            'title'         => __( 'Innerpage Banner Section', 'faceblog' ),
            'priority'      => 6,
            'panel'         => 'faceblog_header_settings_panel'
        )
    );
    
    // Top Header Option
    $wp_customize->add_setting(
        'innerpage_banner_option', 
        array(
              'default' => 0,
              'capability' => 'edit_theme_options',
              'sanitize_callback' => 'faceblog_sanitize_checkbox'
            )
    );
	$wp_customize->add_control(
	    'innerpage_banner_option', 
	    array(
	          'type' => 'checkbox',
	          'label' => __( 'Banner Option', 'faceblog' ),
	          'description' => __( 'Checked to disable header banner for innerpages.', 'faceblog' ),
	          'section' => 'faceblog_innerpage_banner_section',
	          'priority'      => 4
	        )
	);
    
    // Banner image upload
    $wp_customize->add_setting( 
        'header_inner_banner_image',
        array(
            'default' => '',
            'capability'  => 'edit_theme_options',
            'sanitize_callback' => 'esc_url_raw',
            ) 
    );
    $wp_customize->add_control( new WP_Customize_Image_Control( 
        $wp_customize, 
            'header_inner_banner_image', 
            array(
                'label'     => __( 'Banner Image', 'faceblog' ),
                'description'     => __( 'Added banner image for Innerpages header section.', 'faceblog' ),
                'section'   => 'faceblog_innerpage_banner_section',
                'context'   => 'header-banner-image',
                'priority'  => 5
                )
        ) 
    );
}